pub struct Message {Show 24 fields
pub message_id: String,
pub url: String,
pub topic_name: Option<String>,
pub endpoint_name: Option<String>,
pub api: Option<String>,
pub key: Option<String>,
pub method: Option<String>,
pub header: Option<HashMap<String, Vec<String>>>,
pub body: Option<String>,
pub body_base64: Option<String>,
pub max_retries: Option<u32>,
pub retry_delay_expression: Option<String>,
pub not_before: Option<u64>,
pub created_at: u64,
pub callback: Option<String>,
pub failure_callback: Option<String>,
pub queue_name: Option<String>,
pub schedule_id: Option<String>,
pub caller_ip: Option<String>,
pub label: Option<String>,
pub flow_control_key: Option<String>,
pub rate: Option<u32>,
pub period: Option<u32>,
pub parallelism: Option<u32>,
}Expand description
A queued or in-flight QStash message.
Fields
message_id: StringUnique identifier of the message.
url: StringDestination URL.
topic_name: Option<String>URL Group name when the message targets one.
endpoint_name: Option<String>Endpoint label inside the URL Group.
api: Option<String>API name when the message targets a provider integration.
key: Option<String>Custom message key if one was set by the service.
method: Option<String>Delivery method.
header: Option<HashMap<String, Vec<String>>>Forwarded headers.
body: Option<String>UTF-8 body when available.
body_base64: Option<String>Base64-encoded body for non-UTF-8 payloads.
max_retries: Option<u32>Maximum retry count.
retry_delay_expression: Option<String>Retry delay expression when configured.
not_before: Option<u64>Absolute not-before timestamp in milliseconds.
created_at: u64Creation timestamp in milliseconds.
callback: Option<String>Callback URL.
failure_callback: Option<String>Failure callback URL.
queue_name: Option<String>Queue name when the message was enqueued.
schedule_id: Option<String>Schedule identifier when created by a schedule.
caller_ip: Option<String>Caller IP recorded by QStash.
label: Option<String>User-defined label.
flow_control_key: Option<String>Flow control key used for rate limiting.
rate: Option<u32>Flow control rate.
period: Option<u32>Flow control period in seconds.
parallelism: Option<u32>Flow control parallelism.